fn handle_bogie(
q_bogies: &mut Query<'_, '_, &mut TrackPos>,
q_segments: Query<'_, '_, &TrackSegment>,
meters: f32,
bogie: Entity,
) -> boolExpand description
Returns true if the bogie was successfully handled (not derailed)
fn handle_bogie(
q_bogies: &mut Query<'_, '_, &mut TrackPos>,
q_segments: Query<'_, '_, &TrackSegment>,
meters: f32,
bogie: Entity,
) -> boolReturns true if the bogie was successfully handled (not derailed)